# TCAP
TCAP is a Python package for natural language processing tasks, including text cleaning, pre-processing, text stats, feature extraction, feature analysis, model training, and post-model analysis. All in 1 line of code, given the data.

## Installation
You can install TCAP using pip:

pip install TCAP


## Usage
To use TCAP, you'll need a dataframe containing a text column (named 'text') and a target column (named 'target').

## Contributing
If you are interested in contributing to TCAP, please see our CONTRIBUTING guidelines.

## License
TCAP is released under the MIT License.

## Acknowledgements
The TCAP package was developed by Amit Osi. TCAP makes use of the following open-source libraries: NLTK, spaCy, Gensim, Sklearn.
# Chester
Chester is a package for end-to-end machine learning models, including all necessary steps and plots. It creates a report.

## Contributing
If you are interested in contributing to Chester, please see our CONTRIBUTING guidelines.

## License
Chester is released under the MIT License.

## Acknowledgements
The Chester package was developed by Amit Osi.
